@@ -32,7 +32,6 @@ class Context:
         self.__context = context
         if not context.is_ephemeral():
             context.set_cache_model(WebKit2.CacheModel.WEB_BROWSER)
-            context.set_favicon_database_directory(App().favicons_path)
             cookie_manager = context.get_cookie_manager()
             cookie_manager.set_accept_policy(
                 App().settings.get_enum("cookie-storage"))
@@ -41,18 +40,11 @@ class Context:
             WebKit2.ProcessModel.MULTIPLE_SECONDARY_PROCESSES)
         context.set_spell_checking_enabled(
             App().settings.get_value("enable-spell-check"))
-        locales = GLib.get_language_names()
-        try:
-            user_locale = locales[0].split(".")[0]
-            context.set_spell_checking_languages([user_locale])
-        except:
-            pass
         context.register_uri_scheme("populars", self.__on_populars_scheme)
         context.register_uri_scheme("internal", self.__on_internal_scheme)
         context.register_uri_scheme("accept", self.__on_accept_scheme)
         context.register_uri_scheme("file", self.__on_file_scheme)
         context.get_security_manager().register_uri_scheme_as_local("populars")
-        context.get_security_manager().register_uri_scheme_as_local("file")
         # We allow DownloadPopover to connect before default context
         context.connect_after("download-started", self.__on_download_started)
 
