@@ -114,6 +114,8 @@ class ToolbarTitle(Gtk.Bin):
 
         self.__entry = builder.get_object("entry")
         # Inline completion
+        self.__completion_model_append_timeout_id = None
+        self.__completion_model_clear_timeout_id = None
         self.__completion_model = Gtk.ListStore(str)
         self.__completion = Gtk.EntryCompletion.new()
         self.__completion.set_model(self.__completion_model)
@@ -222,6 +224,17 @@ class ToolbarTitle(Gtk.Bin):
         self.__signal_id = self.__entry.connect("changed",
                                                 self.__on_entry_changed)
 
+    def add_dot_com(self):
+        """
+            Add dot com to URI
+        """
+        bounds = self.__entry.get_selection_bounds()
+        if bounds:
+            current = self.__entry.get_text()[:bounds[0]]
+        else:
+            current = self.__entry.get_text()
+        self.set_text_entry(current + ".com")
+
     def set_uri(self, uri):
         """
             Update internal uri
@@ -324,15 +337,15 @@ class ToolbarTitle(Gtk.Bin):
 
     def show_input_warning(self, webview):
         """
-            Show a message to user about password input field over http
+            Show a message to user about password input field over HTTP
             @param webview as WebView
         """
         if self.__input_warning_shown:
             return
         self.__input_warning_shown = True
         self.show_message(_(
-            "Heads-up: this page is not secure.\n"
-            "If you type your password,\n it will be "
+            "Heads-up: This page is insecure.\n"
+            "If you type your password,\nit will be "
             "visible to cybercriminals!"))
 
     def show_readable_button(self, b):
@@ -380,7 +393,7 @@ class ToolbarTitle(Gtk.Bin):
         """
         if indicator == Indicator.GEOLOCATION:
             self.__indicator2.show()
-            self.__indicator2.set_tooltip_text(_("Disallow geolocation"))
+            self.__indicator2.set_tooltip_text(_("Deny geolocation"))
             self.__indicator2_image.set_from_icon_name(
                 "mark-location-symbolic",
                 Gtk.IconSize.MENU)
@@ -438,7 +451,7 @@ class ToolbarTitle(Gtk.Bin):
         if self.__entry.get_icon_name(Gtk.EntryIconPosition.PRIMARY) ==\
                 "edit-copy-symbolic":
             Gtk.Clipboard.get(Gdk.SELECTION_CLIPBOARD).set_text(
-                self.__entry.get_text(),
+                self.__uri,
                 -1)
 
     def _on_enter_notify(self, widget, event):
@@ -781,10 +794,14 @@ class ToolbarTitle(Gtk.Bin):
             @param encoding as str
             @param value as str
         """
-        if status and value == self.__entry.get_text():
+        current_text = self.__entry.get_text()
+        if status and value == current_text:
             string = content.decode(encoding)
             # format: '["{"words"}",["result1","result2"]]'
-            sgs = string.replace('[', '').replace(']', '').split(',')[1:]
+            sgs = string.replace('[', '')\
+                        .replace(']', '')\
+                        .replace('"', '')\
+                        .split(',')[1:]
             self.__popover.add_suggestions(sgs)
 
     def __populate_completion(self, uri):
@@ -792,8 +809,30 @@ class ToolbarTitle(Gtk.Bin):
             @param uri as str
             @thread safe
         """
-        if self.__entry.get_text() == uri:
+        # Thread handling
+        def model_append_timeout(array):
+            self.__completion_model_append_timeout_id = None
+            self.__completion_model.append(array)
+
+        def model_clear_timeout():
+            self.__completion_model_clear_timeout_id = None
             self.__completion_model.clear()
+
+        def model_append(array):
+            if self.__completion_model_clear_timeout_id is not None:
+                GLib.source_remove(self.__completion_model_clear_timeout_id)
+            if self.__completion_model_append_timeout_id is not None:
+                GLib.source_remove(self.__completion_model_append_timeout_id)
+            self.__completion_model_append_timeout_id = \
+                GLib.timeout_add(250, model_append_timeout, array)
+
+        def model_clear():
+            if self.__completion_model_clear_timeout_id is not None:
+                GLib.source_remove(self.__completion_model_clear_timeout_id)
+            self.__completion_model_clear_timeout_id = \
+                GLib.timeout_add(1000, model_clear_timeout)
+
+        if self.__entry.get_text() == uri:
             # Look for a match in history
             match = App().history.get_match(uri)
             if match is not None:
@@ -803,29 +842,28 @@ class ToolbarTitle(Gtk.Bin):
                 netloc = match_parsed.netloc.replace("www.", "")
                 if netloc.find(uri) == 0:
                     if match_parsed.path.find(uri.split("/")[-1]) != -1:
-                        self.__completion_model.append([netloc +
-                                                        match_parsed.path])
+                        model_append([netloc + match_parsed.path])
                     else:
-                        self.__completion_model.append([netloc])
-
-            if not App().settings.get_value("dns-prediction"):
-                return
-            # Try some DNS request, FIXME Better list?
-            from socket import gethostbyname
-            parsed = urlparse(uri)
-            if parsed.netloc:
-                uri = parsed.netloc
-            for suffix in self.__dns_suffixes:
-                for prefix in ["www.", ""]:
-                    try:
-                        lookup = "%s%s.%s" % (prefix, uri, suffix)
-                        gethostbyname(lookup)
-                        self.__completion_model.append(
-                            [lookup.replace("www.", "")])
-                        return
-                    except:
-                        if self.__cancellable.is_cancelled():
+                        model_append([netloc])
+                    return
+            if App().settings.get_value("dns-prediction"):
+                # Try some DNS request, FIXME Better list?
+                from socket import gethostbyname
+                parsed = urlparse(uri)
+                if parsed.netloc:
+                    uri = parsed.netloc
+                for suffix in self.__dns_suffixes:
+                    for prefix in ["www.", ""]:
+                        try:
+                            lookup = "%s%s.%s" % (prefix, uri, suffix)
+                            gethostbyname(lookup)
+                            model_append([lookup.replace("www.", "")])
                             return
+                        except:
+                            if self.__cancellable.is_cancelled():
+                                return
+            # Only happen if nothing matched
+            model_clear()
 
     def __search_in_current_views(self, value):
         """
@@ -850,6 +888,7 @@ class ToolbarTitle(Gtk.Bin):
         """
         self.__cancellable.cancel()
         self.__cancellable.reset()
+        self.__completion_model.clear()
         webview = self.__window.container.current.webview
         if popover == self.__popover:
             webview.grab_focus()
@@ -913,9 +952,9 @@ class ToolbarTitle(Gtk.Bin):
 
         self.__cancellable.cancel()
         self.__cancellable.reset()
-        parsed = urlparse(value)
 
         network = Gio.NetworkMonitor.get_default().get_network_available()
+        parsed = urlparse(value)
         is_uri = parsed.scheme in ["about, http", "file", "https", "populars"]
         if is_uri:
             self.__popover.set_search_text(parsed.netloc + parsed.path)
